@@ -9,11 +9,11 @@
 # or submit itself to any jurisdiction.                                       #
 ###############################################################################
 from .analysis_data import AnalysisData
-from .ap_info import SampleList, fetch_ap_info, load_ap_info_from_single_file
+from .ap_info import SampleCollection, fetch_ap_info, load_ap_info_from_single_file
 
 __all__ = [
     "AnalysisData",
     "fetch_ap_info",
     "load_ap_info_from_single_file",
-    "SampleList",
+    "SampleCollection",
 ]
